@@ -61,9 +61,6 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
   SMTP_EV_INVALID_PEER_CERTIFICATE
   SMTP_EV_NO_PEER_CERTIFICATE
   SMTP_EV_WRONG_PEER_CERTIFICATE
-  SMTP_EV_NO_CLIENT_CERTIFICATE
-  SMTP_EV_UNUSABLE_CLIENT_CERTIFICATE
-  SMTP_EV_UNUSABLE_CA_LIST
   SMTP_CB_HEADERS
   SMTP_CB_READING
   SMTP_CB_WRITING
@@ -189,7 +186,7 @@ our @EXPORT = qw(
   Timeout_OVERRIDE_RFC2822_MINIMUM
 );
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.1';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
